@@ -88,9 +88,7 @@ struct protocol {
 	int(*send)(PROTO_SEND_SIG);	/* How to send a frame */
 	int(*decode)(PROTO_DECODE_SIG); /* How to decode a frame */
 	int(*guess)(PROTO_GUESS_SIG);   /* Can be NULL, use MAC address in this case */
-	u_int8_t	 mac1[ETHER_ADDR_LEN];  /* Destination MAC address used by this protocol */
-	u_int8_t	 mac2[ETHER_ADDR_LEN];  /* Destination MAC address used by this protocol */
-	u_int8_t	 mac3[ETHER_ADDR_LEN];  /* Destination MAC address used by this protocol */
+	u_int8_t	 mac[3][ETHER_ADDR_LEN];  /* Destination MAC addresses used by this protocol */
 };
 
 #define SMART_HIDDEN(port) (port->p_hidden_in)
@@ -194,7 +192,11 @@ client_handle_client(struct lldpd *cfg,
     int*);
 
 /* priv.c */
+#ifdef ENABLE_PRIVSEP
 void	 priv_init(const char*, int, uid_t, gid_t);
+#else
+void	 priv_init(void);
+#endif
 void	 priv_wait(void);
 void	 priv_ctl_cleanup(const char *ctlname);
 char   	*priv_gethostname(void);
